""" Display the histogram of RGB channels from multiple FITS images.

    Calculate the histogram of each color channel for a FITS image
    and display them together on a single plot.
"""

import os
import pyfits

from numpy import histogram, Inf, empty, empty_like

from pylab import bar, show, axis, hold, fill_between

def hist_lines(bins, edges):
    """
    """
    new_bins = empty(len(bins)* 2, dtype=bins.dtype)
    new_bins[::2] = bins
    new_bins[1::2] = bins
    new_edges = empty_like(new_bins)
    new_edges[::2] = edges[:-1]
    new_edges[1::2] = edges[1:]
    return new_bins, new_edges

hold(True)        
    
r_file_path = os.path.join('astro_images', 'm_e_20081203_57_1_1_1.fits')
g_file_path = os.path.join('astro_images', 'm_e_20081203_58_1_1_1.fits')
b_file_path = os.path.join('astro_images', 'm_e_20081203_59_1_1_1.fits')

red_file = pyfits.open(r_file_path)
red = red_file[0].data.clip(0,Inf)

green_file = pyfits.open(g_file_path)
green = green_file[0].data.clip(0,Inf)

blue_file = pyfits.open(b_file_path)
blue = blue_file[0].data.clip(0,Inf)

maximum = max(red.max(), green.max(), blue.max())

r_bins, r_edges = histogram(red, range=(0,maximum), bins=2000)
bins, edges = hist_lines(r_bins, r_edges)
fill_between(edges, bins, edgecolor='none', color='red', alpha=.3)

g_bins, g_edges = histogram(green, range=(0,maximum), bins=2000)
bins, edges = hist_lines(g_bins, g_edges)
fill_between(edges, bins, edgecolor='none', color='green', alpha=.3)

b_bins, b_edges = histogram(blue, range=(0,maximum), bins=2000)
bins, edges = hist_lines(b_bins, b_edges)
fill_between(edges, bins, edgecolor='none', color='blue', alpha=.3)

axis(xmax=400)       
show()
